@@ -67,6 +67,13 @@ namespace giac {
   gen laplace(const gen & f0,const gen & x,const gen & s,GIAC_CONTEXT){
     if (x.type!=_IDNT)
       return gensizeerr(contextptr);
+    if (f0.type==_VECT){
+      vecteur v=*f0._VECTptr;
+      for (int i=0;i<int(v.size());++i){
+	v[i]=laplace(v[i],x,s,contextptr);
+      }
+      return gen(v,f0.subtype);
+    }
     gen t(s);
     if (s==x){
 #ifdef GIAC_HAS_STO_38
@@ -122,7 +129,7 @@ namespace giac {
     if (args.type!=_VECT)
       return laplace(args,vx_var,vx_var,contextptr);
     vecteur & v=*args._VECTptr;
-    int s=v.size();
+    int s=int(v.size());
     if (s==2)
       return laplace( v[0],v[1],v[1],contextptr);
     if (s!=3)
@@ -143,6 +150,8 @@ namespace giac {
     gen res=_laplace_(exact(args,contextptr),contextptr);
 #endif
     approx_mode(b,contextptr);
+    if (b || has_num_coeff(args))
+      res=simplifier(evalf(res,1,contextptr),contextptr);
     return res;
   }
   static const char _laplace_s []="laplace";
@@ -205,7 +214,7 @@ namespace giac {
       if (is_strictly_positive(expa,contextptr))
 	*logptr(contextptr) << gettext("Warning, exponential x coeff is positive ") << expa << endl;
       vecteur varx(lvarx(coeff,x));
-      int varxs=varx.size();
+      int varxs=int(varx.size());
       if (!varxs){ // Dirac function
 	res += coeff*exp(expb,contextptr)*symbolic(at_Dirac,laplace_var+expa);
 	continue;
@@ -221,10 +230,10 @@ namespace giac {
       alg_lvar(makevecteur(coeff,axb),l);
       gen glap=e2r(laplace_var,l,contextptr);
       if (glap.type!=_POLY)  return gensizeerr(gettext("desolve.cc/pf_ilaplace"));
-      int s=l.front()._VECTptr->size();
+      int s=int(l.front()._VECTptr->size());
       if (!s){
 	l.erase(l.begin());
-	s=l.front()._VECTptr->size();
+	s=int(l.front()._VECTptr->size());
       }
       gen r=e2r(coeff,l,contextptr);
       gen r_num,r_den;
@@ -305,7 +314,7 @@ namespace giac {
       }
       vecteur ipnumv=polynome2poly1(ipnum,1);
       gen deno=r2e(ipden,l,contextptr);
-      int nums=ipnumv.size();
+      int nums=int(ipnumv.size());
       for (int i=0;i<nums;++i){
 	gen tmp = rdiv(r2e(ipnumv[i],lprime,contextptr),deno,contextptr);
 	tmp = tmp*symbolic(at_Dirac,(i==nums-1)?laplace_var:gen(makevecteur(laplace_var,nums-1-i),_SEQ__VECT));
@@ -337,7 +346,7 @@ namespace giac {
     if (args.type!=_VECT)
       return ilaplace(args,vx_var,vx_var,contextptr);
     vecteur & v=*args._VECTptr;
-    int s=v.size();
+    int s=int(v.size());
     if (s==2)
       return ilaplace( v[0],v[1],v[1],contextptr);
     if (s!=3)
@@ -466,12 +475,12 @@ namespace giac {
     // special handling for systems
     if (solution_generale.type==_VECT && v.size()==2){
       gen init=v[1],point=0;
-      if (init.is_symb_of_sommet(at_equal)){
-	point=init._SYMBptr->feuille[0];
-	init=init._SYMBptr->feuille[1];
-	if (!point.is_symb_of_sommet(at_of) || point._SYMBptr->feuille[0]!=y)
+      if (init.is_symb_of_sommet(at_equal) && init._SYMBptr->feuille.type==_VECT&& init._SYMBptr->feuille._VECTptr->size()>=2){
+	point=(*init._SYMBptr->feuille._VECTptr)[0];
+	init=(*init._SYMBptr->feuille._VECTptr)[1];
+	if (!point.is_symb_of_sommet(at_of) || point._SYMBptr->feuille.type!=_VECT || point._SYMBptr->feuille._VECTptr->size()<2 || point._SYMBptr->feuille._VECTptr->front()!=y)
 	  return gensizeerr("Bad initial condition");
-	point=point._SYMBptr->feuille[1];
+	point=(*point._SYMBptr->feuille._VECTptr)[1];
       }
       gen systeme=subst(solution_generale,x,point,false,contextptr)-init;
       gen s=_solve(makesequence(systeme,parameters),contextptr);
@@ -579,12 +588,14 @@ namespace giac {
     gen solution_generale(desolve_f(v.front(),x,y,ordre,parameters,f,contextptr));
     if (solution_generale.type!=_VECT) 
       return in_desolve_with_conditions(v,x,y,solution_generale,parameters,f,contextptr);
+    solution_generale.subtype=0; // otherwise desolve([y'=[[1,2],[2,1]]*y+[x,x+1],y(0)=[1,2]]) fails on the Prime (?)
     if (parameters.empty())
       return solution_generale;
-    const_iterateur it=solution_generale._VECTptr->begin(),itend=solution_generale._VECTptr->end();
+    iterateur it=solution_generale._VECTptr->begin(),itend=solution_generale._VECTptr->end();
     vecteur res;
     res.reserve(itend-it);
     for (;it!=itend;++it){
+      if (it->type==_VECT) it->subtype=0;
       gen tmp=in_desolve_with_conditions(v,x,y,*it,parameters,f,contextptr);
       if (is_undef(tmp))
 	return tmp;
@@ -662,7 +673,7 @@ namespace giac {
       // take laplace transform
       // p*Y-Y(0)+bsura*Y+csura=0
       // (p+bsura)*Y=Y(0)-csura
-      int n=a._VECTptr->size();
+      int n=int(a._VECTptr->size());
       if (!ckmatrix(a) || !ckmatrix(b))
 	return gensizeerr(contextptr);
       gen inva=inv(a,contextptr);
@@ -713,7 +724,9 @@ namespace giac {
       gen & b=v[1];
       gen & c=v[2];
       if (ckmatrix(a)){
-	c=_tran(c,contextptr)[a._VECTptr->size()-1];
+	if (c.type!=_VECT && is_zero(c))
+	  c=c*a;
+	c=_tran(c,contextptr)[int(a._VECTptr->size())-1];
       }
       result=desolve_lin1(a,b,c,x,parameters,contextptr);
       return true;
@@ -776,7 +789,7 @@ namespace giac {
 	      bool b=calc_mode(contextptr)==1;
 	      if (b)
 		calc_mode(0,contextptr);
-	      part += _integrate(makesequence(_lin(c[i]*exp(-rac[i]*x,contextptr),contextptr),x),contextptr)*exp(rac[i]*x,contextptr);
+	      part += _lin(_integrate(makesequence(_lin(c[i]*exp(-rac[i]*x,contextptr),contextptr),x),contextptr)*exp(rac[i]*x,contextptr),contextptr);
 	      if (b)
 		calc_mode(1,contextptr);
 	    }
@@ -882,7 +895,7 @@ namespace giac {
 	b=_coeff(makesequence(b,x),contextptr);
 	c=_coeff(makesequence(c,x),contextptr);
 	if (a.type==_VECT && b.type==_VECT && c.type==_VECT){
-	  int A=a._VECTptr->size()-1,B=b._VECTptr->size()-1,C=c._VECTptr->size()-1,N=-1;
+	  int A=int(a._VECTptr->size())-1,B=int(b._VECTptr->size())-1,C=int(c._VECTptr->size())-1,N=-1;
 	  if (C==B-1){
 	    gen n=-c._VECTptr->front()/b._VECTptr->front();
 	    if (n.type==_INT_ && n.val>N){
@@ -915,21 +928,21 @@ namespace giac {
 	      m[i]=vecteur(N+1);
 	    // a*y''
 	    for (int i=0;i<a._VECTptr->size();++i){
-	      int j=a._VECTptr->size()-i-1;
+	      int j=int(a._VECTptr->size())-i-1;
 	      for (int k=2;k<=N;++k){
 		(*m[j+k-2]._VECTptr)[k] += k*(k-1)*a[i];
 	      }
 	    }
 	    // b*y'
 	    for (int i=0;i<b._VECTptr->size();++i){
-	      int j=b._VECTptr->size()-i-1;
+	      int j=int(b._VECTptr->size())-i-1;
 	      for (int k=1;k<=N;++k){
 		(*m[j+k-1]._VECTptr)[k] += k*b[i];
 	      }
 	    }
 	    // c*y
 	    for (int i=0;i<c._VECTptr->size();++i){
-	      int j=c._VECTptr->size()-i-1;
+	      int j=int(c._VECTptr->size())-i-1;
 	      for (int k=0;k<=N;++k){
 		(*m[j+k]._VECTptr)[k] += c[i];
 	      }
@@ -1369,10 +1382,9 @@ namespace giac {
       vecteur lv(lop(args,at_of));
       vecteur f;
       if (lv.size()>=1 && lv[0]._SYMBptr->feuille.type==_VECT && (f=*lv[0]._SYMBptr->feuille._VECTptr).size()==2){
-	gen f1=vx_var;
-	if (f[1].type==_IDNT || f[1].is_symb_of_sommet(at_at))
-	  f1=f[1];
-	return desolve(args,f1,f[0],ordre,parameters,contextptr);
+	if (f[1].type==_IDNT || f[1].is_symb_of_sommet(at_at)){
+	  return desolve(args,f[1],f[0],ordre,parameters,contextptr);
+	}
       }
       gen vx,vy;
       lv=lidnt(evalf(args,1,contextptr));
@@ -1390,7 +1402,7 @@ namespace giac {
       return _desolve(makesequence(args,vx,vy),contextptr);
     }
     vecteur v=*args._VECTptr;
-    int s=v.size();
+    int s=int(v.size());
     for (int i=0;i<s;++i){
       v[i]=apply(v[i],point2vecteur,contextptr);
     }
@@ -1462,7 +1474,7 @@ namespace giac {
     if (args.type!=_VECT)
       return ztrans(args,vx_var,vx_var,contextptr);
     vecteur & v=*args._VECTptr;
-    int s=v.size();
+    int s=int(v.size());
     if (s==2)
       return ztrans( v[0],v[1],v[1],contextptr);
     if (s!=3)
@@ -1490,7 +1502,7 @@ namespace giac {
 #endif
     }
     vecteur varx(lvarx(f,x));
-    int varxs=varx.size();
+    int varxs=int(varx.size());
     gen res;
     if (varxs==0)
       res=f*symb_when(t,1,0);
@@ -1508,10 +1520,10 @@ namespace giac {
       lprime.front()=cdr_VECT(*(lprime.front()._VECTptr));
       gen glap=e2r(s,l,contextptr);
       if (glap.type!=_POLY)  return gensizeerr(gettext("desolve.cc/invztrans"));
-      int dim=l.front()._VECTptr->size();
+      int dim=int(l.front()._VECTptr->size());
       if (!dim){
 	l.erase(l.begin());
-	dim=l.front()._VECTptr->size();
+	dim=int(l.front()._VECTptr->size());
       }
       gen r=e2r(res,l,contextptr);
       res=0;
@@ -1588,7 +1600,7 @@ namespace giac {
     if (args.type!=_VECT)
       return invztrans(args,vx_var,vx_var,contextptr);
     vecteur & v=*args._VECTptr;
-    int s=v.size();
+    int s=int(v.size());
     if (s==2)
       return invztrans( v[0],v[1],v[1],contextptr);
     if (s!=3)
