@@ -21,6 +21,17 @@
 #ifndef _GIAC_FIRST_H_
 #define _GIAC_FIRST_H_
 
+// Thanks to Jason Papadopoulos, author of msieve
+#ifdef BESTA_OS
+#define PREFETCH(addr) /* nothing */
+#elif (defined(__GNUC__) && __GNUC__ >= 3) || defined(__clang__)
+	#define PREFETCH(addr) __builtin_prefetch(addr) 
+#elif defined(_MSC_VER) && _MSC_VER >= 1400
+	#define PREFETCH(addr) PreFetchCacheLine(PF_TEMPORAL_LEVEL_1, addr)
+#else
+	#define PREFETCH(addr) /* nothing */
+#endif
+
 #ifdef PNACL
 #define EMCC
 #undef HAVE_LIBPTHREAD
@@ -48,6 +59,8 @@
 #ifdef EMCC
 #define CERR std::cout
 extern "C" double emcctime(); 
+extern "C" int glinit(int,int,int,int,int);
+extern "C" void glcontext(int);
 #define CLOCK emcctime
 #else
 #define CERR std::cerr
@@ -175,6 +188,9 @@ int my_sprintf(char * s, const char * format, ...);
 #endif
 #endif
 
+#ifdef GIAC_HAS_STO_38
+#define GIAC_GENERIC_CONSTANTS
+#endif
 
 #ifdef __VISUALC__ 
 #define GIAC_GENERIC_CONSTANTS
@@ -208,7 +224,14 @@ typedef unsigned long long ulonglong;
 #endif // __x86_64__
 
 // do not define PSEUDO_MOD if a negative unsigned longlong >> 63 is != 0xffffffffffffffff
-#if defined(FIR) && !(defined(IOS) || defined(__ANDROID__))
+// #define PSEUDO_MOD accelerates cyclic* gbasis computation significantly
+// from int_multilinear_combination in vecteur.cc (from rref?)
+#ifdef FIR
+#if !(defined(BESTA_OS) || defined(WINDOWS))
+// #if !(defined(IOS) || defined(__ANDROID__)) && !defined(OSX) && !defined(LINUX)
+#define PSEUDO_MOD 
+#endif
+#else
 #define PSEUDO_MOD 
 #endif
 
@@ -226,6 +249,11 @@ typedef longlong ref_count_t;
 typedef int ref_count_t;
 #endif
 
+#ifdef WINSTORE
+//tw  **NOTE** this is pulled out of winnt.h!!! I don't know why it is not found there.
+//             there is some sort of interaction in windows ARM builds... 
+#define CP15_TPIDRURW          15, 0, 13,  0, 2         // Software Thread ID Register, User Read/Write
+#endif
 
 #ifndef __x86_64__
 #ifdef SMARTPTR64
@@ -416,7 +444,7 @@ inline float ffloor(float f1){
 #endif
 }
 inline float finv(float f1){ return 1/f1; }
-#if defined __APPLE__ || defined EMCC
+#if defined __APPLE__ || defined EMCC || defined NO_BSD 
 inline float fgamma(float f1){ return tgammaf(f1); }
 #else
 #if defined(__MINGW_H) || defined(VISUALC) // FIXME gamma, not used
